#include "imageLoader.h"
#include "images/data.c"
#include "config.h"

CImageLoader::CImageLoader()
{
}
CImageLoader::~CImageLoader()
{
}
void CImageLoader::LoadImage(QPixmap *img,int type)
{

  switch(type){
  case BOOTLOGO_IMG:
    img->loadFromData(BOOTLOGO_IMG_DATA, sizeof (BOOTLOGO_IMG_DATA));
    break;
  case TITLE_IMG:
    img->loadFromData(TITLEIMAGE_DATA, sizeof (TITLEIMAGE_DATA));
    break;
  case SINGLE_IMG:
    img->loadFromData(SINGLEIMAGE_DATA, sizeof (SINGLEIMAGE_DATA));
    break;
  case VS_IMG:
    img->loadFromData(VSIMAGE_DATA, sizeof (VSIMAGE_DATA));
    break;
  case BLOCK01_IMG:
    img->loadFromData(BLOCK01IMAGE_DATA, sizeof (BLOCK01IMAGE_DATA));
    break;
  case BLOCK02_IMG:
    img->loadFromData(BLOCK02IMAGE_DATA, sizeof (BLOCK02IMAGE_DATA));
    break;
  case RETRY_IMG:
    img->loadFromData(RETRYIMAGE_DATA, sizeof (RETRYIMAGE_DATA));
    break;
  case YES_IMG:
    img->loadFromData(YESIMAGE_DATA, sizeof (YESIMAGE_DATA));
    break;
  case NO_IMG:
    img->loadFromData(NOIMAGE_DATA, sizeof (NOIMAGE_DATA));
    break;

  case BACK_IMG:
    img->loadFromData(BACKIMAGE_DATA, sizeof (BACKIMAGE_DATA));
    break;
  case THINKNOW_IMG:
    img->loadFromData(THINKNOWIMAGE_DATA, sizeof (THINKNOWIMAGE_DATA));
    break;
  case LOGO2_IMG:
    img->loadFromData(LOGO2IMAGE_DATA, sizeof (LOGO2IMAGE_DATA));
    break; 
  case WIN1_IMG:
    img->loadFromData(WIN1IMAGE_DATA, sizeof (WIN1IMAGE_DATA));
    break;    
  case WIN2_IMG:
    img->loadFromData(WIN2IMAGE_DATA, sizeof (WIN2IMAGE_DATA));
    break;  
  case YOULOST_IMG:
    img->loadFromData(YOULOSTIMAGE_DATA, sizeof (YOULOSTIMAGE_DATA));
    break;  
  case YOUWIN_IMG:
    img->loadFromData(YOUWINIMAGE_DATA, sizeof (YOUWINIMAGE_DATA));
    break;  
  case DRAWGAME_IMG:
    img->loadFromData(DRAWGAMEIMGAE_DATA , sizeof (DRAWGAMEIMGAE_DATA));
    break; 

  case TAIGA01_IMG:
    img->loadFromData(TAIGA01IMAGE_DATA, sizeof (TAIGA01IMAGE_DATA));
    break;
  case TAIGA02_IMG:
    img->loadFromData(TAIGA02IMAGE_DATA, sizeof (TAIGA02IMAGE_DATA));
    break;
  case TAIGA04_IMG:
    img->loadFromData(TAIGA04IMAGE_DATA, sizeof (TAIGA04IMAGE_DATA));
    break;

  case PEN01_IMG:
    img->loadFromData(PEN01IMAGE_DATA, sizeof (PEN01IMAGE_DATA));
    break;
  case PEN02_IMG:
    img->loadFromData(PEN02IMAGE_DATA, sizeof (PEN02IMAGE_DATA));
    break;
  case PEN04_IMG:
    img->loadFromData(PEN04IMAGE_DATA, sizeof (PEN04IMAGE_DATA));
    break;

  case TAKU01_IMG:
    img->loadFromData(TAKU01IMAGE_DATA, sizeof (TAKU01IMAGE_DATA));
    break;
  case TAKU02_IMG:
    img->loadFromData(TAKU02IMAGE_DATA, sizeof (TAKU02IMAGE_DATA));
    break;
  case TAKU04_IMG:
    img->loadFromData(TAKU04IMAGE_DATA, sizeof (TAKU04IMAGE_DATA));
    break;

  case P_ATTACK_IMG:
    img->loadFromData(P_ATTACKIMAGE_DATA,sizeof(P_ATTACKIMAGE_DATA));
    break;
  case A_ATTACK_IMG:
    img->loadFromData(A_ATTACKIMAGE_DATA,sizeof(A_ATTACKIMAGE_DATA));
    break;

  default:
    break;
  }

}

